@@ -27,7 +27,12 @@ def ssh_connection(config) -> SSHClient:
     client.load_system_host_keys()
     try:
         print(f"Try to connect to {config.hostname!r}...")
-        client.connect(config.hostname, username=config.username, password=config.password, timeout=config.timeout)
+        client.connect(
+            config.hostname,
+            username=config.username,
+            password=config.password,
+            timeout=config.timeout,
+        )
         return client
     except socket.gaierror as exc:
         raise RuntimeError(f"{exc}") from exc
